==> s-render-0.1.0.tgz: package/es/FormRender/widgets/container/TableList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
import "antd/es/card/style";
import _Card from "antd/es/card";
import "antd/es/table/style";
import _Table from "antd/es/table";
import _ImportOutlined from "@ant-design/icons/lib/icons/ImportOutlined";
import _PlusOutlined from "@ant-design/icons/lib/icons/PlusOutlined";
import "antd/es/space/style";
import _Space from "antd/es/space";
import "antd/es/popconfirm/style";
import _Popconfirm from "antd/es/popconfirm";
import "antd/es/button/style";
import _Button from "antd/es/button";
var _excluded = ["schema", "record", "dataIndex", "title", "index", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import { cloneDeep } from 'lodash-es';
import { useRef } from 'react';
import { filterSchema } from "../../utils";
import ImportModal from "../components/ImportModal";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TableList = function TableList(props) {
  var rootPath = props.rootPath,
    schema = props.schema,
    renderItem = props.renderItem,
    fields = props.fields,
    addItem = props.addItem,
    moveItem = props.moveItem,
    copyItem = props.copyItem,
    removeItem = props.removeItem,
    form = props.form,
    operation = props.operation;
  var importModalRef = useRef();
  var extraButtonStyle = {
    padding: 0
  };
  var onMove = function onMove(from, to) {
    return function () {
      moveItem(from, to);
    };
  };
  var onDelete = function onDelete(name) {
    return function () {
      removeItem(name);
    };
  };
  var onCopy = function onCopy(name) {
    return function () {
      var value = form.getFieldValue(rootPath.concat(name));
      copyItem(value !== null && value !== void 0 ? value : {});
    };
  };
  var columns = filterSchema(schema === null || schema === void 0 ? void 0 : schema.properties).map(function (key) {
    var item = schema === null || schema === void 0 ? void 0 : schema.properties[key];
    return {
      dataIndex: key,
      title: item === null || item === void 0 ? void 0 : item.title,
      onCell: function onCell(record) {
        return {
          record: record,
          schema: item,
          dataIndex: key,
          title: item === null || item === void 0 ? void 0 : item.title
        };
      }
    };
  }).concat([{
    title: '操作',
    dataIndex: 'action',
    fixed: 'right',
    width: 165,
    onCell: function onCell(record) {
      return {
        record: record,
        dataIndex: 'action'
      };
    },
    render: function render(_, record) {
      return /*#__PURE__*/_jsxs(_Space, {
        children: [/*#__PURE__*/_jsx(_Button, {
          type: "link",
          disabled: (record === null || record === void 0 ? void 0 : record.name) === 0,
          style: extraButtonStyle,
          onClick: onMove(record === null || record === void 0 ? void 0 : record.name, (record === null || record === void 0 ? void 0 : record.name) - 1),
          children: "\u4E0A\u79FB"
        }), /*#__PURE__*/_jsx(_Button, {
          type: "link",
          style: extraButtonStyle,
          disabled: (record === null || record === void 0 ? void 0 : record.name) === fields.length - 1,
          onClick: onMove(record === null || record === void 0 ? void 0 : record.name, (record === null || record === void 0 ? void 0 : record.name) + 1),
          children: "\u4E0B\u79FB"
        }), /*#__PURE__*/_jsx(_Popconfirm, {
          title: "\u786E\u5B9A\u5220\u9664\u5417\uFF1F",
          onConfirm: onDelete(record === null || record === void 0 ? void 0 : record.name),
          children: /*#__PURE__*/_jsx(_Button, {
            type: "link",
            danger: true,
            style: extraButtonStyle,
            children: "\u5220\u9664"
          })
        }), /*#__PURE__*/_jsx(_Button, {
          type: "link",
          style: extraButtonStyle,
          onClick: onCopy(record === null || record === void 0 ? void 0 : record.name),
          children: "\u590D\u5236"
        })]
      });
    }
  }]);
  var EditableCell = function EditableCell(props) {
    var schema = props.schema,
      record = props.record,
      dataIndex = props.dataIndex,
      title = props.title,
      index = props.index,
      children = props.children,
      otherProps = _objectWithoutProperties(props, _excluded);
    if (dataIndex === 'action') {
      return /*#__PURE__*/_jsx("td", _objectSpread(_objectSpread({}, otherProps), {}, {
        children: children
      }));
    }
    return /*#__PURE__*/_jsx("td", _objectSpread(_objectSpread({}, otherProps), {}, {
      children: schema && renderItem({
        schema: schema,
        path: [record === null || record === void 0 ? void 0 : record.name, dataIndex],
        rootPath: rootPath,
        key: dataIndex,
        tableInline: true
      })
    }));
  };
  var onAddClick = function onAddClick() {
    addItem({});
  };

  /**
   * 打开导入弹窗
   */
  var importClick = function importClick() {
    var _importModalRef$curre;
    (_importModalRef$curre = importModalRef.current) === null || _importModalRef$curre === void 0 ? void 0 : _importModalRef$curre.onOpen();
  };
  var importOk = function importOk(list) {
    var _list = cloneDeep(list);
    while (_list.length > 0) {
      var item = _list.shift();
      addItem(item);
    }
  };
  return /*#__PURE__*/_jsxs(_Card, {
    title: schema === null || schema === void 0 ? void 0 : schema.title,
    size: "small",
    extra: /*#__PURE__*/_jsxs(_Space, {
      children: [/*#__PURE__*/_jsx(_Button, {
        icon: /*#__PURE__*/_jsx(_PlusOutlined, {}),
        type: "primary",
        size: "small",
        onClick: onAddClick,
        children: "\u6DFB\u52A0"
      }), (schema === null || schema === void 0 ? void 0 : schema.isImport) && /*#__PURE__*/_jsx(_Button, {
        icon: /*#__PURE__*/_jsx(_ImportOutlined, {}),
        size: "small",
        onClick: importClick,
        children: "\u5BFC\u5165"
      })]
    }),
    children: [/*#__PURE__*/_jsx(_Table, {
      columns: columns,
      size: "small",
      dataSource: fields !== null && fields !== void 0 ? fields : [],
      pagination: false,
      components: {
        body: {
          cell: EditableCell
        }
      }
    }), /*#__PURE__*/_jsx(ImportModal, {
      title: schema === null || schema === void 0 ? void 0 : schema.title,
      onOk: importOk,
      ref: importModalRef,
      schema: (schema === null || schema === void 0 ? void 0 : schema.properties) || {}
    })]
  });
};
export default TableList;

==> s-render-0.1.3.tgz: package/es/FormRender/widgets/container/TableList.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
import "antd/es/card/style";
import _Card from "antd/es/card";
import "antd/es/table/style";
import _Table from "antd/es/table";
import _ImportOutlined from "@ant-design/icons/lib/icons/ImportOutlined";
import _PlusOutlined from "@ant-design/icons/lib/icons/PlusOutlined";
import "antd/es/space/style";
import _Space from "antd/es/space";
import "antd/es/popconfirm/style";
import _Popconfirm from "antd/es/popconfirm";
import "antd/es/button/style";
import _Button from "antd/es/button";
var _excluded = ["schema", "record", "dataIndex", "title", "index", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import { cloneDeep } from 'lodash-es';
import { useRef } from 'react';
import { filterSchema } from "../../utils";
import ImportModal from "../components/ImportModal";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TableList = function TableList(props) {
  var rootPath = props.rootPath,
    schema = props.schema,
    renderItem = props.renderItem,
    fields = props.fields,
    addItem = props.addItem,
    moveItem = props.moveItem,
    copyItem = props.copyItem,
    removeItem = props.removeItem,
    form = props.form,
    operation = props.operation;
  var importModalRef = useRef();
  var extraButtonStyle = {
    padding: 0
  };
  var onMove = function onMove(from, to) {
    return function () {
      moveItem(from, to);
    };
  };
  var onDelete = function onDelete(name) {
    return function () {
      removeItem(name);
    };
  };
  var onCopy = function onCopy(name) {
    return function () {
      var value = form.getFieldValue(rootPath.concat(name));
      copyItem(value !== null && value !== void 0 ? value : {});
    };
  };
  var columns = filterSchema(schema === null || schema === void 0 ? void 0 : schema.properties).filter(function (key) {
    var _schema$properties, _schema$properties$ke;
    return (schema === null || schema === void 0 ? void 0 : (_schema$properties = schema.properties) === null || _schema$properties === void 0 ? void 0 : (_schema$properties$ke = _schema$properties[key]) === null || _schema$properties$ke === void 0 ? void 0 : _schema$properties$ke.hidden) !== true;
  }).map(function (key) {
    var item = schema === null || schema === void 0 ? void 0 : schema.properties[key];
    return {
      dataIndex: key,
      title: item === null || item === void 0 ? void 0 : item.title,
      onCell: function onCell(record) {
        return {
          record: record,
          schema: item,
          dataIndex: key,
          title: item === null || item === void 0 ? void 0 : item.title
        };
      }
    };
  }).concat([{
    title: '操作',
    dataIndex: 'action',
    fixed: 'right',
    width: 165,
    onCell: function onCell(record) {
      return {
        record: record,
        dataIndex: 'action'
      };
    },
    render: function render(_, record) {
      return /*#__PURE__*/_jsxs(_Space, {
        children: [/*#__PURE__*/_jsx(_Button, {
          type: "link",
          disabled: (record === null || record === void 0 ? void 0 : record.name) === 0,
          style: extraButtonStyle,
          onClick: onMove(record === null || record === void 0 ? void 0 : record.name, (record === null || record === void 0 ? void 0 : record.name) - 1),
          children: "\u4E0A\u79FB"
        }), /*#__PURE__*/_jsx(_Button, {
          type: "link",
          style: extraButtonStyle,
          disabled: (record === null || record === void 0 ? void 0 : record.name) === fields.length - 1,
          onClick: onMove(record === null || record === void 0 ? void 0 : record.name, (record === null || record === void 0 ? void 0 : record.name) + 1),
          children: "\u4E0B\u79FB"
        }), /*#__PURE__*/_jsx(_Popconfirm, {
          title: "\u786E\u5B9A\u5220\u9664\u5417\uFF1F",
          onConfirm: onDelete(record === null || record === void 0 ? void 0 : record.name),
          children: /*#__PURE__*/_jsx(_Button, {
            type: "link",
            danger: true,
            style: extraButtonStyle,
            children: "\u5220\u9664"
          })
        }), /*#__PURE__*/_jsx(_Button, {
          type: "link",
          style: extraButtonStyle,
          onClick: onCopy(record === null || record === void 0 ? void 0 : record.name),
          children: "\u590D\u5236"
        })]
      });
    }
  }]);
  var EditableCell = function EditableCell(props) {
    var schema = props.schema,
      record = props.record,
      dataIndex = props.dataIndex,
      title = props.title,
      index = props.index,
      children = props.children,
      otherProps = _objectWithoutProperties(props, _excluded);
    if (dataIndex === 'action') {
      return /*#__PURE__*/_jsx("td", _objectSpread(_objectSpread({}, otherProps), {}, {
        children: children
      }));
    }
    return /*#__PURE__*/_jsx("td", _objectSpread(_objectSpread({}, otherProps), {}, {
      children: schema && renderItem({
        schema: schema,
        path: [record === null || record === void 0 ? void 0 : record.name, dataIndex],
        rootPath: rootPath,
        key: dataIndex,
        tableInline: true
      })
    }));
  };
  var onAddClick = function onAddClick() {
    addItem({});
  };

  /**
   * 打开导入弹窗
   */
  var importClick = function importClick() {
    var _importModalRef$curre;
    (_importModalRef$curre = importModalRef.current) === null || _importModalRef$curre === void 0 ? void 0 : _importModalRef$curre.onOpen();
  };
  var importOk = function importOk(list) {
    var _list = cloneDeep(list);
    while (_list.length > 0) {
      var item = _list.shift();
      addItem(item);
    }
  };
  return /*#__PURE__*/_jsxs(_Card, {
    title: schema === null || schema === void 0 ? void 0 : schema.title,
    size: "small",
    extra: /*#__PURE__*/_jsxs(_Space, {
      children: [/*#__PURE__*/_jsx(_Button, {
        icon: /*#__PURE__*/_jsx(_PlusOutlined, {}),
        type: "primary",
        size: "small",
        onClick: onAddClick,
        children: "\u6DFB\u52A0"
      }), (schema === null || schema === void 0 ? void 0 : schema.isImport) && /*#__PURE__*/_jsx(_Button, {
        icon: /*#__PURE__*/_jsx(_ImportOutlined, {}),
        size: "small",
        onClick: importClick,
        children: "\u5BFC\u5165"
      })]
    }),
    children: [/*#__PURE__*/_jsx(_Table, {
      columns: columns,
      size: "small",
      dataSource: fields !== null && fields !== void 0 ? fields : [],
      pagination: false,
      components: {
        body: {
          cell: EditableCell
        }
      }
    }), /*#__PURE__*/_jsx(ImportModal, {
      title: schema === null || schema === void 0 ? void 0 : schema.title,
      onOk: importOk,
      ref: importModalRef,
      schema: (schema === null || schema === void 0 ? void 0 : schema.properties) || {}
    })]
  });
};
export default TableList;
